export const ImageTypeLabels = {
  alibaba: "Alibaba Cloud (.qcow2)",
  ami: "Amazon Web Services (.raw)",
  "iot-commit": "IoT Commit (.tar)",
  google: "Google Cloud Platform (.vhd)",
  "hyper-v": "Hyper-V (.vhd)",
  "live-iso": "Installer, suitable for USB and DVD (.iso)",
  tar: "Disk Archive (.tar)",
  openstack: "OpenStack (.qcow2)",
  "partitioned-disk": "Disk Image (.img)",
  oci: "Oracle Cloud Infrastructure (.qcow2)",
  qcow2: "QEMU Image (.qcow2)",
  "rhel-edge-commit": "RHEL for Edge Commit (.tar)",
  "rhel-edge-container": "RHEL for Edge Container (.tar)",
  "rhel-edge-installer": "RHEL for Edge Installer (.iso)",
  "edge-commit": "RHEL for Edge Commit (.tar)",
  "edge-container": "RHEL for Edge Container (.tar)",
  "edge-installer": "RHEL for Edge Installer (.iso)",
  "edge-raw-image": "RHEL for Edge Raw Image (.raw.xz)",
  "image-installer": "RHEL Installer (.iso)",
  "edge-simplified-installer": "RHEL for Edge Simplified Installer (.iso)",
  vhd: "Microsoft Azure (.vhd)",
  vmdk: "VMWare VSphere (.vmdk)",
  gce: "Google Cloud Platform (.tar.gz)",
};

export const UNIT_KIB = 1024 ** 1;
export const UNIT_MIB = 1024 ** 2;
export const UNIT_GIB = 1024 ** 3;
